use gtk4 as gtk;
use gtk::{glib, gio, prelude::*, subclass::prelude::*};
use crate::application;

mod imp {
    use super::*;

    #[derive(Default, Debug)]
    pub struct TabbedWindow {
        pub inner_panel: gtk::Notebook,
    }

    #[glib::object_subclass]
    impl ObjectSubclass for TabbedWindow {
        const NAME: &'static str = "TabbedWindow";
        type Type = super::TabbedWindow;
        type ParentType = gtk::ApplicationWindow;
    }

    impl ObjectImpl for TabbedWindow {
        fn constructed(&self) {
            self.parent_constructed();
            self.obj().set_child(Some(&self.inner_panel));
        }
    }

    impl WidgetImpl for TabbedWindow {}
    impl WindowImpl for TabbedWindow {}
    impl ApplicationWindowImpl for TabbedWindow {}
}

glib::wrapper! {
    pub struct TabbedWindow(ObjectSubclass<imp::TabbedWindow>)
        @extends gtk::Widget, gtk::Window, gtk::ApplicationWindow,
        @implements gio::ActionMap, gio::ActionGroup;
}

impl TabbedWindow {
    pub fn new(app: &application::Application, tabs: &[(&str, &gtk::Widget)]) -> Self {
        let obj: Self = glib::Object::builder().property("application", app).build();
        for tab in tabs {
            obj.add_tab(tab.0, tab.1);
        }
        obj.clone()
    }

    pub fn add_tab<P: glib::IsA<gtk::Widget>>(&self, title: &str, content: &P) {
        self.imp().inner_panel.append_page(content, Some(&gtk::Label::new(Some(title))));
    }
}
